@@ -2,7 +2,7 @@
 //
 /****************************************************************************
    liblscp - LinuxSampler Control Protocol API
-   Copyright (C) 2004-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
 static WSADATA _wsaData;
 #endif
 
+
 ////////////////////////////////////////////////////////////////////////
 
 lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer, int cchBuffer, void *pvData )
@@ -43,7 +44,10 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 	static int iSamplerChannel = 0;
 	static int iAudioDevice = 0;
 	static int iMidiDevice  = 0;
+	static int iFxSend = 0;
+	static int iMidiMaps = 0;
 	static int iMidiInstruments = 0;
+	static float fVolume = 1.0f;
 
 	if (pchBuffer == NULL) {
 		fprintf(stderr, "server_callback: addr=%s port=%d: ",
@@ -411,15 +415,57 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 			sprintf(szTemp, "%d\r\n", rand() % 100);
 			pszResult = szTemp;
 		}
+		else if (lscp_parser_test(&tok, "VOLUME")) {
+			// Get global volume attenuation:
+			// GET VOLUME
+			sprintf(szTemp, "%g\r\n", fVolume);
+			pszResult = szTemp;
+		}
+		else if (lscp_parser_test2(&tok, "FX_SEND", "INFO")) {
+			// Getting effect send informations:
+			// GET FX_SEND INFO <sampler-channel> <fx-send-id>
+			pszResult = "NAME: DummyFxSend\r\n"
+						"MIDI_CONTROLLER: 99\r\n"
+						"AUDIO_OUTPUT_ROUTING: 0,1\r\n"
+						"LEVEL: 0.15\r\n"
+						".\r\n";
+		}
+		else if (lscp_parser_test(&tok, "FX_SENDS")) {
+			// Get ammount of effect sends on a sampler channel:
+			// GET FX_SENDS <sampler-channel>
+			sprintf(szTemp, "%d\r\n", iFxSend);
+			pszResult = szTemp;
+		}
 		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENTS")) {
 			// Get the total count of MIDI instrument map entries:
 			// GET MIDI_INSTRUMENTS
 			sprintf(szTemp, "%d\r\n", iMidiInstruments);
 			pszResult = szTemp;
 		}
-		if (lscp_parser_test2(&tok, "MIDI_INSTRUMENT", "INFO")) {
+		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENT_MAPS")) {
+			// Get the total count of MIDI instrument maps:
+			// GET MIDI_INSTRUMENT_MAPS
+			sprintf(szTemp, "%d\r\n", iMidiMaps);
+			pszResult = szTemp;
+		}
+		else if (lscp_parser_test2(&tok, "MIDI_INSTRUMENT_MAP", "INFO")) {
 			// Getting information about a MIDI instrument map entry:
-			// GET MIDI_INSTRUMENT INFO <midi-bank-msb> <midi-bank-lsb> <midi-prog>
+			// GET MIDI_INSTRUMENT_MAP INFO <midi-map>
+			strcpy(szTemp, "NAME: ");
+			switch (lscp_parser_nextint(&tok)) {
+			case 0:
+				strcat(szTemp, "Chromatic\r\n");
+				break;
+			case 1:
+				strcat(szTemp, "Drum Kits\r\n");
+				break;
+			}
+			strcat(szTemp, ".\r\n");
+			pszResult = szTemp;
+		}
+		else if (lscp_parser_test2(&tok, "MIDI_INSTRUMENT", "INFO")) {
+			// Getting information about a MIDI instrument map entry:
+			// GET MIDI_INSTRUMENT INFO <midi-map> <midi-bank> <midi-prog>
 			pszResult = "NAME: DummyName\r\n"
 						"ENGINE_NAME: DummyEngine\r\n"
 						"INSTRUMENT_FILE: DummyInstrument.gig\r\n"
@@ -435,6 +481,7 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 		if (lscp_parser_test(&tok, "CHANNELS")) {
 			// Getting all created sampler channel list.
 			// LIST CHANNELS
+			szTemp[0] = (char) 0;
 			for (i = 0; i < iSamplerChannel && strlen(szTemp) < sizeof(szTemp) - 8; i++) {
 				if (i > 0)
 					strcat(szTemp, ",");
@@ -461,6 +508,7 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 		else if (lscp_parser_test(&tok, "AUDIO_OUTPUT_DEVICES")) {
 			// Getting all created audio output device list.
 			// LIST AUDIO_OUTPUT_DEVICES
+			szTemp[0] = (char) 0;
 			for (i = 0; i < iAudioDevice && strlen(szTemp) < sizeof(szTemp) - 8; i++) {
 				if (i > 0)
 					strcat(szTemp, ",");
@@ -472,6 +520,7 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 		else if (lscp_parser_test(&tok, "MIDI_INPUT_DEVICES")) {
 			// Getting all created MID input device list.
 			// LIST MIDI_INPUT_DEVICES
+			szTemp[0] = (char) 0;
 			for (i = 0; i < iMidiDevice && strlen(szTemp) < sizeof(szTemp) - 8; i++) {
 				if (i > 0)
 					strcat(szTemp, ",");
@@ -480,9 +529,22 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 			strcat(szTemp, "\r\n");
 			pszResult = szTemp;
 		}
+		else if (lscp_parser_test(&tok, "FX_SENDS")) {
+			// Listing all effect sends on a sampler channel:
+			// LIST FX_SENDS <sampler-channel>
+			szTemp[0] = (char) 0;
+			for (i = 0; i < iFxSend && strlen(szTemp) < sizeof(szTemp) - 8; i++) {
+				if (i > 0)
+					strcat(szTemp, ",");
+				sprintf(szTemp + strlen(szTemp), "%d", i);
+			}
+			strcat(szTemp, "\r\n");
+			pszResult = szTemp;
+		}
 		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENTS")) {
 			// Getting indeces of all MIDI instrument map entries:
 			// LIST MIDI_INSTRUMENTS
+			szTemp[0] = (char) 0;
 			for (i = 0; i < iMidiInstruments && strlen(szTemp) < sizeof(szTemp) - 16; i++) {
 				if (i > 0)
 					strcat(szTemp, ",");
@@ -491,6 +553,18 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 			strcat(szTemp, "\r\n");
 			pszResult = szTemp;
 		}
+		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENT_MAPS")) {
+			// Getting indeces of all MIDI instrument map entries:
+			// LIST MIDI_INSTRUMENT_MAPS
+			szTemp[0] = (char) 0;
+			for (i = 0; i < iMidiMaps && strlen(szTemp) < sizeof(szTemp) - 8; i++) {
+				if (i > 0)
+					strcat(szTemp, ",");
+				sprintf(szTemp + strlen(szTemp), "%d", i);
+			}
+			strcat(szTemp, "\r\n");
+			pszResult = szTemp;
+		}
 		else ret = LSCP_FAILED;
 	}
 	else if (lscp_parser_test(&tok, "SET")) {
@@ -535,8 +609,36 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 				// Setting MIDI input channel:
 				// SET CHANNEL MIDI_INPUT_CHANNEL <sampler-channel> <midi-input-chan>
 			}
+			else if (lscp_parser_test(&tok, "MIDI_INSTRUMENT_MAP")) {
+				// Setting MIDI instrument mapl:
+				// SET CHANNEL MIDI_INSTRUMENT_MAP <sampler-channel> <midi-map>
+			}
 			else ret = LSCP_FAILED;
 		}
+		else if (lscp_parser_test(&tok, "VOLUME")) {
+			// Setting global volume attenuation:
+			// SET VOLUME <volume>
+			fVolume = lscp_parser_nextnum(&tok);
+		}
+		else if (lscp_parser_test(&tok, "FX_SEND")) {
+			if (lscp_parser_test(&tok, "MIDI_CONTROLLER")) {
+				// Altering effect send MIDI controller:
+				// SET FX_SEND MIDI_CONTROLLER <sampler-channel> <fx-send-id> <midi-ctrl>
+			}
+			else if (lscp_parser_test(&tok, "AUDIO_OUTPUT_CHANNEL")) {
+				// Altering effect send audio routing:
+				// SET FX_SEND AUDIO_OUTPUT_CHANNEL <sampler-channel> <fx-send-id> <midi-ctrl> <audio-src> <audio-dst>
+			}
+			else if (lscp_parser_test(&tok, "LEVEL")) {
+				// Altering effect send audio level:
+				// SET FX_SEND LEVEL <sampler-channel> <fx-send-id> <midi-ctrl> <volume>
+			}
+			else ret = LSCP_FAILED;
+		}
+		else if (lscp_parser_test2(&tok, "MIDI_INSTRUMENT_MAP", "NAME")) {
+			// Setting MIDI instrument map name:
+			// SET MIDI_INSTRUMENT_MAP NAME <midi-map> <map-name>
+		}
 		else ret = LSCP_FAILED;
 	}
 	else if (lscp_parser_test(&tok, "LOAD")) {
@@ -550,24 +652,47 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 		}
 		else ret = LSCP_FAILED;
 	}
-	else if (lscp_parser_test2(&tok, "ADD", "CHANNEL")) {
-		// Adding a new sampler channel:
-		// ADD CHANNEL
-		if (iSamplerChannel < 16) {
-			sprintf(szTemp, "OK[%d]\r\n", iSamplerChannel++);
-			pszResult = szTemp;
-		} else {
-			iSamplerChannel = 0;
-			ret = LSCP_FAILED;
+	else if (lscp_parser_test(&tok, "ADD")) {
+		if (lscp_parser_test(&tok, "CHANNEL")) {
+			// Adding a new sampler channel:
+			// ADD CHANNEL
+			if (iSamplerChannel < 16) {
+				sprintf(szTemp, "OK[%d]\r\n", iSamplerChannel++);
+				pszResult = szTemp;
+			} else {
+				iSamplerChannel = 0;
+				ret = LSCP_FAILED;
+			}
+		}
+		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENT_MAP")) {
+			// Adding a new MIDI instrument map:
+			// ADD MIDI_INSTRUMENT_MAP <map-name>
+			if (iMidiMaps < 2) {
+				sprintf(szTemp, "OK[%d]\r\n", iMidiMaps++);
+				pszResult = szTemp;
+			} else {
+				iMidiMaps = 0;
+				ret = LSCP_FAILED;
+			}
 		}
 	}
-	else if (lscp_parser_test2(&tok, "REMOVE", "CHANNEL")) {
-		// Removing a sampler channel:
-		// REMOVE CHANNEL <sampler-channel>
-		if (lscp_parser_nextint(&tok) < iSamplerChannel)
-			iSamplerChannel--;
-		else
-			ret = LSCP_FAILED;
+	else if (lscp_parser_test(&tok, "REMOVE")) {
+		if (lscp_parser_test(&tok, "CHANNEL")) {
+			// Removing a sampler channel:
+			// REMOVE CHANNEL <sampler-channel>
+			if (lscp_parser_nextint(&tok) >= 0)
+				iSamplerChannel--;
+			else
+				ret = LSCP_FAILED;
+		}
+		else if (lscp_parser_test(&tok, "MIDI_INSTRUMENT_MAP")) {
+			// Removing a MIDI instrument map:
+			// REMOVE MIDI_INSTRUMENT_MAP <midi-map>
+			if (lscp_parser_nextint(&tok) >= 0)
+				iMidiMaps--;
+			else
+				ret = LSCP_FAILED;
+		}
 	}
 	else if (lscp_parser_test(&tok, "RESET")) {
 		if (lscp_parser_test(&tok, "CHANNEL")) {
@@ -581,6 +706,8 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 			iSamplerChannel = 0;
 			iAudioDevice = 0;
 			iMidiDevice = 0;
+			iMidiMaps = 0;
+			iMidiInstruments = 0;
 		}
 	}
 	else if (lscp_parser_test(&tok, "CREATE")) {
@@ -606,13 +733,24 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 				ret = LSCP_FAILED;
 			}
 		}
+		else if (lscp_parser_test(&tok, "FX_SEND")) {
+			// Adding an effect send to a sampler channel:
+			// CREATE FX_SEND <sampler-channel> <midi-ctrl> [<name>]
+			if (iFxSend < 8) {
+				sprintf(szTemp, "OK[%d]\r\n", iFxSend++);
+				pszResult = szTemp;
+			} else {
+				iFxSend = 0;
+				ret = LSCP_FAILED;
+			}
+		}
 		else ret = LSCP_FAILED;
 	}
 	else if (lscp_parser_test(&tok, "DESTROY")) {
 		if (lscp_parser_test(&tok, "AUDIO_OUTPUT_DEVICE")) {
 			// Destroying an audio output device.
 			// DESTROY AUDIO_OUTPUT_DEVICE <audio-device-id>
-			if (lscp_parser_nextint(&tok) < iAudioDevice)
+			if (lscp_parser_nextint(&tok) >= 0 && iAudioDevice > 0)
 				iAudioDevice--;
 			else
 				ret = LSCP_FAILED;
@@ -620,22 +758,30 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 		else if (lscp_parser_test(&tok, "MIDI_INPUT_DEVICE")) {
 			// Destroying an MIDI intput device.
 			// DESTROY MIDI_INPUT_DEVICE <midi-device-id>
-			if (lscp_parser_nextint(&tok) < iMidiDevice)
+			if (lscp_parser_nextint(&tok) >= 0 && iMidiDevice > 0)
 				iMidiDevice--;
 			else
 				ret = LSCP_FAILED;
 		}
+		else if (lscp_parser_test(&tok, "FX_SEND")) {
+			// Removing an effect send from a sampler channel:
+			// CREATE FX_SEND <sampler-channel> <fx-send-id>
+			if (lscp_parser_nextint(&tok) >= 0 && iFxSend > 0)
+				iFxSend--;
+			else
+				ret = LSCP_FAILED;
+		}
 		else ret = LSCP_FAILED;
 	}
 	else if (lscp_parser_test2(&tok, "MAP", "MIDI_INSTRUMENT")) {
 		// Create or replace a MIDI instrumnet map entry:
-		// MAP MIDI_INSTRUMENT <midi-bank-msb> <midi-bank-lsb> <midi-prog>
+		// MAP MIDI_INSTRUMENT <midi-map> <midi-bank> <midi-prog>
 		// <engine-name> <filename> <instr-index> <volume> <load-mode> [<name>]
 		iMidiInstruments++;
 	}
 	else if (lscp_parser_test2(&tok, "UNMAP", "MIDI_INSTRUMENT")) {
 		// Remove an entry from the MIDI instrument map:
-		// UNMAP MIDI_INSTRUMENT <midi-bank-msb> <midi-bank-lsb> <midi-prog>
+		// UNMAP MIDI_INSTRUMENT <midi-map> <midi-bank> <midi-prog>
 		if (iMidiInstruments > 0)
 			iMidiInstruments--;
 		else
@@ -644,6 +790,7 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 	else if (lscp_parser_test2(&tok, "CLEAR", "MIDI_INSTRUMENTS")) {
 		// Clear the MIDI instrumnet map:
 		// CLEAR MIDI_INSTRUMENTS
+		iMidiInstruments = 0;
 	}
 	else if (lscp_parser_test(&tok, "SUBSCRIBE")) {
 		// Register frontend for receiving event notification messages:
@@ -673,6 +820,7 @@ lscp_status_t server_callback ( lscp_connect_t *pConnect, const char *pchBuffer,
 	return lscp_server_result(pConnect, pszResult, strlen(pszResult));
 }
 
+
 ////////////////////////////////////////////////////////////////////////
 
 
