@@ -2,7 +2,7 @@
 //
 /****************************************************************************
    liblscp - LinuxSampler Control Protocol API
-   Copyright (C) 2004-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -754,19 +754,19 @@ lscp_midi_instrument_t *lscp_midi_instruments_create ( const char *pszCsv )
 		case '{':
 			pchHead = pch + 1;
 			if (k == 0) {
-				pInstrs[i].bank_msb = atoi(pchHead);
+				pInstrs[i].map = atoi(pchHead);
 				k++;
 			}
 			break;
 		case ',':
 			pchHead = pch + 1;
 			if (k == 1) {
-				pInstrs[i].bank_lsb = atoi(pchHead);
+				pInstrs[i].bank = atoi(pchHead);
 				k++;
 			}
 			else 
 			if (k == 2) {
-				pInstrs[i].program = atoi(pchHead);
+				pInstrs[i].prog = atoi(pchHead);
 				k++;
 			}
 			break;
@@ -783,9 +783,9 @@ lscp_midi_instrument_t *lscp_midi_instruments_create ( const char *pszCsv )
 			pNewInstrs = (lscp_midi_instrument_t *) malloc(iSize * sizeof(lscp_midi_instrument_t));
 			if (pNewInstrs) {
 				for (j = 0; j < i; j++) {
-					pNewInstrs[j].bank_msb = pInstrs[j].bank_msb;
-					pNewInstrs[j].bank_lsb = pInstrs[j].bank_lsb;
-					pNewInstrs[j].program  = pInstrs[j].program;
+					pNewInstrs[j].map  = pInstrs[j].map;
+					pNewInstrs[j].bank = pInstrs[j].bank;
+					pNewInstrs[j].prog = pInstrs[j].prog;
 				}
 				free(pInstrs);
 				pInstrs = pNewInstrs;
@@ -795,9 +795,9 @@ lscp_midi_instrument_t *lscp_midi_instruments_create ( const char *pszCsv )
 	
 	// Special terminate split array.
 	for ( ; i < iSize; i++) {
-		pInstrs[i].bank_msb = -1;
-		pInstrs[i].bank_lsb = -1;
-		pInstrs[i].program  = -1;
+		pInstrs[i].map  = -1;
+		pInstrs[i].bank = -1;
+		pInstrs[i].prog = -1;
 	}
 	
 	return pInstrs;
@@ -835,8 +835,9 @@ int lscp_midi_instruments_size ( lscp_midi_instrument_t *pInstrs )
 
 void lscp_server_info_init ( lscp_server_info_t *pServerInfo )
 {
-	pServerInfo->description = NULL;
-	pServerInfo->version     = NULL;
+	pServerInfo->description      = NULL;
+	pServerInfo->version          = NULL;
+	pServerInfo->protocol_version = NULL;
 }
 
 void lscp_server_info_free ( lscp_server_info_t *pServerInfo )
@@ -845,6 +846,8 @@ void lscp_server_info_free ( lscp_server_info_t *pServerInfo )
 		free(pServerInfo->description);
 	if (pServerInfo->version)
 		free(pServerInfo->version);
+	if (pServerInfo->protocol_version)
+		free(pServerInfo->protocol_version);
 }
 
 void lscp_server_info_reset ( lscp_server_info_t *pServerInfo )
@@ -894,6 +897,7 @@ void lscp_channel_info_init ( lscp_channel_info_t *pChannelInfo )
 	pChannelInfo->midi_device       = 0;
 	pChannelInfo->midi_port         = 0;
 	pChannelInfo->midi_channel      = 0;
+	pChannelInfo->midi_map          = 0;
 	pChannelInfo->volume            = 0.0;
 	pChannelInfo->mute              = 0;
 	pChannelInfo->solo              = 0;
@@ -904,7 +908,7 @@ void lscp_channel_info_free ( lscp_channel_info_t *pChannelInfo )
 	if (pChannelInfo->engine_name)
 		free(pChannelInfo->engine_name);
 	if (pChannelInfo->audio_routing)
-		lscp_szsplit_destroy(pChannelInfo->audio_routing);
+		lscp_isplit_destroy(pChannelInfo->audio_routing);
 	if (pChannelInfo->instrument_file)
 		free(pChannelInfo->instrument_file);
 	if (pChannelInfo->instrument_name)
@@ -1058,6 +1062,32 @@ int lscp_param_concat ( char *pszBuffer, int cchMaxBuffer, lscp_param_t *pParams
 }
 
 
+//-------------------------------------------------------------------------
+// Effect struct helper functions.
+
+void lscp_fxsend_info_init ( lscp_fxsend_info_t *pFxSendInfo )
+{
+	pFxSendInfo->name            = NULL;
+	pFxSendInfo->midi_controller = 0;
+	pFxSendInfo->audio_routing   = NULL;
+	pFxSendInfo->level           = 0.0f;
+}
+
+void lscp_fxsend_info_free ( lscp_fxsend_info_t *pFxSendInfo )
+{
+	if (pFxSendInfo->name)
+		free(pFxSendInfo->name);
+	if (pFxSendInfo->audio_routing)
+		lscp_isplit_destroy(pFxSendInfo->audio_routing);
+}
+
+void lscp_fxsend_info_reset (lscp_fxsend_info_t *pFxSendInfo )
+{
+	lscp_fxsend_info_free(pFxSendInfo);
+	lscp_fxsend_info_init(pFxSendInfo);
+}
+
+
 //-------------------------------------------------------------------------
 // MIDI instrument info struct helper functions.
 
